
    import * as React from 'react';

    import { IconType } from '../types';

    type SiEverydotorgProps = React.ComponentPropsWithoutRef<'svg'> & {
      /**
       * The title provides an accessible short text description to the SVG
       */
      title?: string;
      /**
       * Hex color or color name or "default" to use the default hex for each icon
       */
      color?: string;
      /**
       * The size of the Icon.
       */
      size?: string | number;
    }

    const defaultColor = '#2BD7B0';

    const SiEverydotorg: IconType = React.forwardRef<SVGSVGElement, SiEverydotorgProps>(function SiEverydotorg({title = 'Every.org', color = 'currentColor', size = 24, ...others }, ref) {
      if (color === 'default') {
        color = defaultColor;
      }

      return (
        <svg
          xmlns='http://www.w3.org/2000/svg'
          width={size}
          height={size}
          fill={color}
          viewBox='0 0 24 24'
          ref={ref}
          {...others}
        >
          <title>{title}</title>
          <path d='M18.151 9.36c0-4.467-3.728-7.855-8.517-7.855C4.278 1.505 0 6.028 0 11.63c0 6.038 4.808 10.864 11.28 10.864 6.474 0 12.266-5.13 12.72-11.848h-2.953c-.549 5.034-4.807 8.896-9.766 8.896-4.77 0-8.31-3.502-8.31-7.912 0-3.975 2.953-7.174 6.663-7.174 3.104 0 5.546 2.12 5.546 4.903 0 2.309-1.666 4.24-3.88 4.24v2.952c3.918 0 6.851-3.274 6.851-7.192' />
        </svg>
      );
    });

    export { SiEverydotorg as default, defaultColor };
  