
    import * as React from 'react';

    import { IconType } from '../types';

    type SiFormbricksProps = React.ComponentPropsWithoutRef<'svg'> & {
      /**
       * The title provides an accessible short text description to the SVG
       */
      title?: string;
      /**
       * Hex color or color name or "default" to use the default hex for each icon
       */
      color?: string;
      /**
       * The size of the Icon.
       */
      size?: string | number;
    }

    const defaultColor = '#00C4B8';

    const SiFormbricks: IconType = React.forwardRef<SVGSVGElement, SiFormbricksProps>(function SiFormbricks({title = 'Formbricks', color = 'currentColor', size = 24, ...others }, ref) {
      if (color === 'default') {
        color = defaultColor;
      }

      return (
        <svg
          xmlns='http://www.w3.org/2000/svg'
          width={size}
          height={size}
          fill={color}
          viewBox='0 0 24 24'
          ref={ref}
          {...others}
        >
          <title>{title}</title>
          <path d='M8.658 0a5.714 5.714 0 0 0-5.715 5.714v1.532h14.49a3.623 3.623 0 0 0 0-7.246ZM2.943 8.377v7.246h14.49a3.623 3.623 0 0 0 0-7.246zm0 8.377v3.623a3.623 3.623 0 0 0 7.246 0v-3.623z' />
        </svg>
      );
    });

    export { SiFormbricks as default, defaultColor };
  